==> rendition-12.0.1.tgz: package/dist_esm5/components/ProgressBar/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import assign from 'lodash/assign';
import find from 'lodash/find';
import get from 'lodash/get';
import * as React from 'react';
import { withProps } from 'recompose';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { px } from '../../utils';
var transition = 'width linear 250ms';
var Bar = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tposition: relative;\n\theight: ", ";\n\toverflow: hidden;\n\tbackground: ", ";\n\ttransition: ", ";\n\ttext-align: center;\n"], ["\n\tposition: relative;\n\theight: ",
    ";\n\toverflow: hidden;\n\tbackground: ", ";\n\ttransition: ", ";\n\ttext-align: center;\n"])), function (props) {
    return px(props.emphasized ? props.theme.space[5] : props.theme.space[4]);
}, function (props) { return props.bg || props.theme.colors.primary.main; }, transition);
var LoadingContent = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tbottom: 0;\n\tright: 0;\n\ttext-align: center;\n\tcolor: #000;\n\ttext-shadow: 0 0 3px rgba(255, 255, 255, 0.5);\n"], ["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tbottom: 0;\n\tright: 0;\n\ttext-align: center;\n\tcolor: #000;\n\ttext-shadow: 0 0 3px rgba(255, 255, 255, 0.5);\n"])));
var Content = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\ttext-align: center;\n\tposition: absolute;\n\tleft: 0;\n\tbottom: 0;\n\ttop: 0;\n\ttext-shadow: 0 0 3px rgba(0, 0, 0, 0.5);\n\ttransition: ", ";\n"], ["\n\ttext-align: center;\n\tposition: absolute;\n\tleft: 0;\n\tbottom: 0;\n\ttop: 0;\n\ttext-shadow: 0 0 3px rgba(0, 0, 0, 0.5);\n\ttransition: ", ";\n"])), transition);
var Sleeve = styled.div(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\tposition: relative;\n\tborder-radius: ", ";\n\theight: ", ";\n\tline-height: ", ";\n\tbackground: ", ";\n\tfont-size: ", "em;\n\toverflow: hidden;\n"], ["\n\tposition: relative;\n\tborder-radius: ", ";\n\theight: ",
    ";\n\tline-height: ",
    ";\n\tbackground: ", ";\n\tfont-size: ", "em;\n\toverflow: hidden;\n"])), function (props) { return px(props.theme.radius); }, function (props) {
    return px(props.emphasized ? props.theme.space[4] : props.theme.space[3]);
}, function (props) {
    return px(props.emphasized ? props.theme.space[4] : props.theme.space[3]);
}, function (props) { return props.theme.colors.quartenary.main; }, function (props) { return (props.emphasized ? 1 : 0.6); });
var getType = withProps(function (props) {
    var type = find(Object.keys(props), function (b) {
        return find(Object.keys(props.theme.colors), function (k) { return k === b; });
    });
    return assign({}, props, { type: type });
});
var setTypeProps = withProps(function (_a) {
    var type = _a.type, theme = _a.theme, background = _a.background, color = _a.color;
    var themeBackground = get(theme.colors[type || 'primary'], 'main');
    return {
        color: color || '#fff',
        background: background || themeBackground,
    };
});
var Base = function (_a) {
    var children = _a.children, background = _a.background, value = _a.value, props = __rest(_a, ["children", "background", "value"]);
    return (React.createElement(Sleeve, __assign({}, props),
        React.createElement(LoadingContent, null, children),
        React.createElement(Bar, { bg: background, style: { width: value + "%" } },
            React.createElement(Content, { style: { width: (value && (100 * 100) / value) + "%" } }, children))));
};
export default asRendition(Base, [getType, setTypeProps], ['color']);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4;

==> rendition-18.4.1.tgz: package/dist_esm5/components/ProgressBar/index.js <==
import { __assign, __makeTemplateObject, __rest } from "tslib";
import find from 'lodash/find';
import * as React from 'react';
import { withProps } from 'recompose';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { px } from '../../utils';
var transition = 'width linear 250ms';
var Bar = styled.div(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tposition: relative;\n\theight: ", ";\n\toverflow: hidden;\n\tbackground: ", ";\n\ttransition: ", ";\n\ttext-align: center;\n"], ["\n\tposition: relative;\n\theight: ",
    ";\n\toverflow: hidden;\n\tbackground: ", ";\n\ttransition: ", ";\n\ttext-align: center;\n"])), function (props) {
    return px(props.emphasized ? props.theme.space[5] : props.theme.space[4]);
}, function (props) { return props.bg || props.theme.colors.primary.main; }, transition);
var LoadingContent = styled.div(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tbottom: 0;\n\tright: 0;\n\ttext-align: center;\n\tcolor: #000;\n\ttext-shadow: 0 0 3px rgba(255, 255, 255, 0.5);\n"], ["\n\tposition: absolute;\n\ttop: 0;\n\tleft: 0;\n\tbottom: 0;\n\tright: 0;\n\ttext-align: center;\n\tcolor: #000;\n\ttext-shadow: 0 0 3px rgba(255, 255, 255, 0.5);\n"])));
var Content = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\ttext-align: center;\n\tposition: absolute;\n\tleft: 0;\n\tbottom: 0;\n\ttop: 0;\n\ttext-shadow: 0 0 3px rgba(0, 0, 0, 0.5);\n\ttransition: ", ";\n"], ["\n\ttext-align: center;\n\tposition: absolute;\n\tleft: 0;\n\tbottom: 0;\n\ttop: 0;\n\ttext-shadow: 0 0 3px rgba(0, 0, 0, 0.5);\n\ttransition: ", ";\n"])), transition);
var Sleeve = styled.div(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\tposition: relative;\n\tborder-radius: ", ";\n\theight: ", ";\n\tline-height: ", ";\n\tbackground: ", ";\n\tfont-size: ", "em;\n\toverflow: hidden;\n"], ["\n\tposition: relative;\n\tborder-radius: ", ";\n\theight: ",
    ";\n\tline-height: ",
    ";\n\tbackground: ", ";\n\tfont-size: ", "em;\n\toverflow: hidden;\n"])), function (props) { return px(props.theme.radius); }, function (props) {
    return px(props.emphasized ? props.theme.space[4] : props.theme.space[3]);
}, function (props) {
    return px(props.emphasized ? props.theme.space[4] : props.theme.space[3]);
}, function (props) { return props.theme.colors.quartenary.main; }, function (props) { return (props.emphasized ? 1 : 0.6); });
var getType = withProps(function (props) {
    var type = find(Object.keys(props), function (b) {
        return find(Object.keys(props.theme.colors), function (k) { return k === b; });
    });
    return Object.assign({}, props, { type: type });
});
var setTypeProps = withProps(function (_a) {
    var _b;
    var type = _a.type, theme = _a.theme, background = _a.background, color = _a.color;
    var themeBackground = (_b = theme.colors[type || 'primary']) === null || _b === void 0 ? void 0 : _b.main;
    return {
        color: color || '#fff',
        background: background || themeBackground,
    };
});
var Base = function (_a) {
    var children = _a.children, background = _a.background, value = _a.value, props = __rest(_a, ["children", "background", "value"]);
    return (React.createElement(Sleeve, __assign({}, props),
        React.createElement(LoadingContent, null, children),
        React.createElement(Bar, { bg: background, style: { width: value + "%" } },
            React.createElement(Content, { style: { width: (value && (100 * 100) / value) + "%" } }, children))));
};
export default asRendition(Base, [getType, setTypeProps], ['color']);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4;
